# AgentConnectorUserStats

The user status for an agent, eg. when a user last logged in 

## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**user_stats** | [**[AgentConnectorPerUserStats]**](AgentConnectorPerUserStats.md) | The status for any user connector functionality for this agent  | 
**any string name** | **bool, date, datetime, dict, float, int, list, str, none_type** | any string name can be used but the value must be the correct type | [optional]

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


